@@ -3,4 +3,6 @@ module Aws.Lambda
   ) where
 
 import Aws.Lambda.Configuration as Reexported
+import Aws.Lambda.Runtime as Reexported
 import Aws.Lambda.Runtime.Context as Reexported
+import Aws.Lambda.Runtime.ApiGatewayInfo as Reexported
