@@ -1,12 +1,9 @@
 {-# OPTIONS_GHC -fno-warn-unused-pattern-binds #-}
 module Aws.Lambda.Configuration
   ( Main.LambdaOptions(..)
-  , Main.generate
-  , Main.getRecord
-  , configureLambda
-  , IPC.returnAndFail
-  , IPC.returnAndSucceed
+  , generateLambdaDispatcher
   , Dispatch.decodeObj
+  , Dispatch.encodeObj
   )
 where
 
@@ -15,13 +12,11 @@ import qualified Language.Haskell.TH as Meta
 import qualified Aws.Lambda.Meta.Dispatch as Dispatch
 import qualified Aws.Lambda.Meta.Main as Main
 import qualified Aws.Lambda.Meta.Run as Run
-import qualified Aws.Lambda.Runtime.IPC as IPC
 
-{-| Generates a @main@ function to be used with the
-AWS Lambda layer.
+{-| Generates a @main@ function that acts as a dispatcher
 -}
-configureLambda :: Meta.DecsQ
-configureLambda = do
+generateLambdaDispatcher :: Main.DispatcherStrategy -> Main.DispatcherOptions -> Meta.DecsQ
+generateLambdaDispatcher strategy options = do
   main <- Main.generate
-  run <- Run.generate
+  run <- Run.generate options strategy
   return (main <> [run])
