@@ -1,6 +1,6 @@
 {-| Discovery of AWS Lambda handlers
 A handler is basically a function that has a type definition that
-starts with "handler :: ".
+starts with "handler " and two colons.
  -}
 module Aws.Lambda.Meta.Discover
   ( handlers
@@ -15,6 +15,14 @@ import qualified Data.Text as Text
 import Path
 import qualified Path.IO as PathIO
 
+-- | Paths to ignore during compilation
+ignoredPaths :: [Text]
+ignoredPaths =
+  [ "node_modules"
+  , ".stack-work"
+  , ".serverless"
+  ]
+
 {-| Returns a list of handler paths that look like
 
 @src/Foo/Bar/Quux.handler@
@@ -34,7 +42,12 @@ modulesWithHandler files =
   & Monad.filterM containsHandler
  where
   isHaskellModule file =
-    fileExtension file == ".hs"
+    fileExtension file == Just ".hs"
+    && isNotIgnoredPath file
+
+  isNotIgnoredPath file =
+    filter (\ignoredPath -> ignoredPath `Text.isInfixOf` (Text.pack $ toFilePath file)) ignoredPaths
+    & null
 
 handlerNames :: [Path Rel File] -> [Text]
 handlerNames modules =
@@ -48,4 +61,7 @@ handlerNames modules =
 containsHandler :: Path Rel File -> IO Bool
 containsHandler file = do
   fileContents <- readFile $ toFilePath file
-  pure $ "handler :: " `Text.isInfixOf` Text.pack fileContents
+  lines fileContents
+    & filter (Text.isPrefixOf "handler :: " . Text.pack)
+    & (not . null)
+    & pure
